To install

pip install khbr

Setup an environment variable called "USE_KH2_GITPATH" which points to one level above your extracted KH2 directory (which should be called KH2)

Run extract_data.py to extract the MSN/ARD/OBJ BAR files, which are required to properly generate the mod

Run generate_randomizations.py to pre generate the randomizations for when boss mode == "one_to_one" (currently these are dummy randomizations that won't be stable)
    Note the folder generated by this script should either be in the khbr library directory, or at the same directory as your KH2 folder
    